@@ -4,18 +4,19 @@ import numpy as np
 from numpy import ndarray
 from pyFAI import AzimuthalIntegrator
 
-from pdfstream.integration.tools import bg_sub, auto_mask, vis_img, integrate, vis_chi
+from pdfstream.integration.tools import bg_sub, vis_img, integrate, vis_chi, auto_mask
 
 
 def get_chi(
     ai: AzimuthalIntegrator,
     img: ndarray,
     bg_img: ndarray = None,
+    mask: ndarray = None,
     bg_scale: float = None,
-    mask_setting: dict = None,
+    mask_setting: tp.Union[str, dict] = None,
     integ_setting: dict = None,
-    img_setting: dict = None,
-    plot_setting: dict = None
+    img_setting: tp.Union[str, dict] = None,
+    plot_setting: tp.Union[str, dict] = None,
 ) -> tp.Tuple[
     ndarray,
     dict,
@@ -41,11 +42,14 @@ def get_chi(
     bg_img : ndarray
         The 2D array of the background image. If None, no background subtraction.
 
+    mask : ndarray
+        A mask provided by user. The auto generated mask will be multiplied by this mask.
+
     bg_scale : float
         The scale for background subtraction. If None, use 1.
 
     mask_setting : dict
-        The auto mask setting.
+        The auto final_mask setting.
         If None, use _AUTOMASK_SETTING in the tools module. To turn off the auto masking, use "OFF".
 
     integ_setting : dict
@@ -70,8 +74,8 @@ def get_chi(
     img : ndarray
         The background subtrated image. If no background subtraction, return the input image.
 
-    mask : ndarray or None
-        The mask array. If no auto_masking, return None.
+    final_mask : ndarray or None
+        The final_mask array. If no auto_masking, return None.
 
     _mask_setting : dict or str
         The auto masking seeting.
@@ -79,15 +83,17 @@ def get_chi(
     if bg_img is not None:
         img = bg_sub(img, bg_img, bg_scale=bg_scale)
     if mask_setting != "OFF":
-        mask, _mask_setting = auto_mask(img, ai, mask_setting=mask_setting)
+        final_mask, _mask_setting = auto_mask(img, ai, user_mask=mask, mask_setting=mask_setting)
+    elif mask is not None:
+        final_mask, _mask_setting = mask, {}
     else:
-        mask, _mask_setting = None, None
+        final_mask, _mask_setting = None, None
     if img_setting != "OFF":
-        vis_img(img, mask, img_setting=img_setting)
-    chi, _integ_setting = integrate(img, ai, mask=mask, integ_setting=integ_setting)
+        vis_img(img, final_mask, img_setting=img_setting)
+    chi, _integ_setting = integrate(img, ai, mask=final_mask, integ_setting=integ_setting)
     if plot_setting != "OFF":
         vis_chi(chi, plot_setting=plot_setting, unit=_integ_setting.get('unit'))
-    return chi, _integ_setting, img, mask, _mask_setting
+    return chi, _integ_setting, img, final_mask, _mask_setting
 
 
 def avg_imgs(imgs: tp.Iterable[ndarray], weights: tp.Iterable[float] = None) -> ndarray:
